@@ -9,6 +9,8 @@ logger = logging.getLogger(__name__)
 
 @dataclass()
 class Simulation:
+    """Data class holding the attributes of the 'simulation' element inside OspSystemStructure.xml."""
+
     name: Union[str, None] = None
     start_time: Union[float, None] = None
     stop_time: Union[float, None] = None
@@ -16,11 +18,11 @@ class Simulation:
     _algorithm: Union[str, None] = None
 
     @property
-    def algorithm(self) -> Union[str, None]:
+    def algorithm(self) -> Union[str, None]:  # noqa: D102
         return self._algorithm
 
     @algorithm.setter
-    def algorithm(self, value: str):
+    def algorithm(self, value: str):  # noqa: D102
         valid_values: list[str] = [
             "fixedStep",
         ]
